from .core import (
    demojize as demojize,
    distinct_emoji_lis as distinct_emoji_lis,
    distinct_emoji_list as distinct_emoji_list,
    emoji_count as emoji_count,
    emoji_lis as emoji_lis,
    emoji_list as emoji_list,
    emojize as emojize,
    get_emoji_regexp as get_emoji_regexp,
    is_emoji as is_emoji,
    replace_emoji as replace_emoji,
    version as version,
)
from .unicode_codes import (
    EMOJI_ALIAS_UNICODE_ENGLISH as EMOJI_ALIAS_UNICODE_ENGLISH,
    EMOJI_DATA as EMOJI_DATA,
    EMOJI_UNICODE_ENGLISH as EMOJI_UNICODE_ENGLISH,
    EMOJI_UNICODE_FRENCH as EMOJI_UNICODE_FRENCH,
    EMOJI_UNICODE_GERMAN as EMOJI_UNICODE_GERMAN,
    EMOJI_UNICODE_ITALIAN as EMOJI_UNICODE_ITALIAN,
    EMOJI_UNICODE_PORTUGUESE as EMOJI_UNICODE_PORTUGUESE,
    EMOJI_UNICODE_SPANISH as EMOJI_UNICODE_SPANISH,
    UNICODE_EMOJI_ALIAS_ENGLISH as UNICODE_EMOJI_ALIAS_ENGLISH,
    UNICODE_EMOJI_ENGLISH as UNICODE_EMOJI_ENGLISH,
    UNICODE_EMOJI_FRENCH as UNICODE_EMOJI_FRENCH,
    UNICODE_EMOJI_GERMAN as UNICODE_EMOJI_GERMAN,
    UNICODE_EMOJI_ITALIAN as UNICODE_EMOJI_ITALIAN,
    UNICODE_EMOJI_PORTUGUESE as UNICODE_EMOJI_PORTUGUESE,
    UNICODE_EMOJI_SPANISH as UNICODE_EMOJI_SPANISH,
)
